@@ -1,9 +1,10 @@
 #' @title Show an interactive visual network representation
 #'   of your drake project.
-#' \lifecycle{stable}
-#' @description To save time for repeated plotting,
-#' this function is divided into
-#' [drake_graph_info()] and [render_drake_graph()].
+#' `r lifecycle::badge("stable")`
+#' @description It is good practice to visualize the dependency graph
+#'   before running the targets.
+#' @details For enhanced interactivity in the graph, see the `mandrake`
+#'   package: <https://mstr3336.github.io/mandrake/>.
 #' @export
 #' @seealso [render_drake_graph()], [sankey_drake_graph()],
 #'   [drake_ggraph()], [text_drake_graph()]
@@ -136,10 +137,12 @@ body(vis_drake_graph) <- config_util_body(vis_drake_graph_impl)
 
 #' @title Render a visualization using the data frames
 #'   generated by [drake_graph_info()].
-#' \lifecycle{stable}
+#' `r lifecycle::badge("stable")`
 #' @description This function is called inside
 #' [vis_drake_graph()], which typical users
 #' call more often.
+#' @details For enhanced interactivity in the graph, see the `mandrake`
+#'   package: <https://mstr3336.github.io/mandrake/>.
 #' @export
 #' @seealso [vis_drake_graph()], [sankey_drake_graph()],
 #'   [drake_ggraph()]
@@ -245,6 +248,8 @@ render_drake_graph <- function(
   )
   out <- visNetwork::visHierarchicalLayout(graph = out, direction = "LR")
   out <- vis_add_on_select(graph = out, on_select = on_select)
+  out$x$nodes$x <- graph_info$nodes$x
+  out$x$nodes$y <- graph_info$nodes$y
   vis_render_webshot(graph = out, file = file, selfcontained = selfcontained)
 }
 
